BEGIN;
SET client_min_messages TO WARNING;

SELECT plan(5);
SELECT tsp_types_check('pgr_tsp');

SELECT finish();
ROLLBACK;
